@@ -45,6 +45,53 @@ static const guint8 radio_frame[] =
   "\0\0\0\0\0\0\0\0\0\0\0\0"};
 
 
+/* GdkPixbuf RGBA C-Source image dump */
+
+#ifdef __SUNPRO_C
+#pragma align 4 (radio_inner)
+#endif
+#ifdef __GNUC__
+static const guint8 radio_inner[] __attribute__ ((__aligned__ (4))) = 
+#else
+static const guint8 radio_inner[] = 
+#endif
+{ ""
+  /* Pixbuf magic (0x47646b50) */
+  "GdkP"
+  /* length: header (24) + pixel_data (676) */
+  "\0\0\2\274"
+  /* pixdata_type (0x1010002) */
+  "\1\1\0\2"
+  /* rowstride (52) */
+  "\0\0\0""4"
+  /* width (13) */
+  "\0\0\0\15"
+  /* height (13) */
+  "\0\0\0\15"
+  /* pixel_data: */
+  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
+  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\4"
+  "\0\0\0v\0\0\0\356\0\0\0\377\0\0\0\366\0\0\0\220\0\0\0\12\0\0\0\0\0\0"
+  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0,\0\0\0\337\0\0\0\354\0\0\0z\0\0\0"
+  ":\0\0\0g\0\0\0\334\0\0\0\357\0\0\0J\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\4\0"
+  "\0\0\337\0\0\0\274\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\224"
+  "\0\0\0\345\0\0\0*\0\0\0\0\0\0\0\0\0\0\0v\0\0\0\354\0\0\0\0\0\0\0\0\0"
+  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\325\0\0\0\223\0\0\0\0\0"
+  "\0\0\0\0\0\0\356\0\0\0\203\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
+  "\0\0\0\0\0\0\0\0\0\0b\0\0\0\350\0\0\0\0\0\0\0\0\0\0\0\377\0\0\0K\0\0"
+  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0,\0\0\0\374"
+  "\0\0\0\0\0\0\0\0\0\0\0\366\0\0\0y\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
+  "\0\0\0\0\0\0\0\0\0\0\0\0\0U\0\0\0\357\0\0\0\0\0\0\0\0\0\0\0\220\0\0\0"
+  "\341\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\306"
+  "\0\0\0\244\0\0\0\0\0\0\0\0\0\0\0\12\0\0\0\360\0\0\0\240\0\0\0\0\0\0\0"
+  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0v\0\0\0\356\0\0\0""8\0\0\0\0\0\0\0\0"
+  "\0\0\0\0\0\0\0K\0\0\0\347\0\0\0\331\0\0\0h\0\0\0,\0\0\0T\0\0\0\307\0"
+  "\0\0\356\0\0\0n\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0*\0\0\0"
+  "\224\0\0\0\350\0\0\0\374\0\0\0\356\0\0\0\244\0\0\0""8\0\0\0\0\0\0\0\0"
+  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
+  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"};
+
+
 /* GdkPixbuf RGBA C-Source image dump */
 
 #ifdef __SUNPRO_C
@@ -294,125 +341,6 @@ static const guint8 slider_light[] =
   "\0\0\0\0\0\0\0\0\0\0"};
 
 
-/* GdkPixbuf RGBA C-Source image dump */
-
-#ifdef __SUNPRO_C
-#pragma align 4 (slider_v)
-#endif
-#ifdef __GNUC__
-static const guint8 slider_v[] __attribute__ ((__aligned__ (4))) = 
-#else
-static const guint8 slider_v[] = 
-#endif
-{ ""
-  /* Pixbuf magic (0x47646b50) */
-  "GdkP"
-  /* length: header (24) + pixel_data (1092) */
-  "\0\0\4\\"
-  /* pixdata_type (0x1010002) */
-  "\1\1\0\2"
-  /* rowstride (52) */
-  "\0\0\0""4"
-  /* width (13) */
-  "\0\0\0\15"
-  /* height (21) */
-  "\0\0\0\25"
-  /* pixel_data: */
-  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\25\0\0\0\263\0\0\0\325\0\0\0\377\0\0\0"
-  "\325\0\0\0\263\0\0\0\25\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
-  "[\0\0\0\363\0\0\0\234\0\0\0P\0\0\0""9\0\0\0O\0\0\0\227\0\0\0\360\0\0"
-  "\0[\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0[\0\0\0\332\0\0\0\77\0\0\0\0\0\0\0\0"
-  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0:\0\0\0\322\0\0\0[\0\0\0\0\0\0\0\25\0\0"
-  "\0\364\0\0\0=\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
-  "\0\0\0""8\0\0\0\361\0\0\0\25\0\0\0t\0\0\0\237\0\0\0\0\0\0\0\0\0\0\0\0"
-  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\225\0\0\0t\0\0"
-  "\0\325\0\0\0S\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
-  "\0\0\0\0\0\0\0\0\0\0\0J\0\0\0\325\0\0\0\377\0\0\0""9\0\0\0\0\0\0\0\0"
-  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0""2\0\0"
-  "\0\377\0\0\0\377\0\0\0""9\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
-  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0""2\0\0\0\377\0\0\0\377\0\0\0""9\0"
-  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
-  "\0\0\0\0""2\0\0\0\377\0\0\0\377\0\0\0""9\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
-  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0""2\0\0\0\377\0\0\0"
-  "\377\0\0\0""9\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
-  "\0\0\0\0\0\0\0\0\0\0\0""2\0\0\0\377\0\0\0\377\0\0\0""9\0\0\0\0\0\0\0"
-  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0""2\0"
-  "\0\0\377\0\0\0\377\0\0\0""9\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
-  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0""2\0\0\0\377\0\0\0\377\0\0\0""9"
-  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
-  "\0\0\0\0\0""2\0\0\0\377\0\0\0\377\0\0\0""9\0\0\0\0\0\0\0\0\0\0\0\0\0"
-  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0""2\0\0\0\377\0\0"
-  "\0\325\0\0\0O\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
-  "\0\0\0\0\0\0\0\0\0\0\0H\0\0\0\325\0\0\0t\0\0\0\235\0\0\0\0\0\0\0\0\0"
-  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\224\0\0"
-  "\0t\0\0\0\25\0\0\0\365\0\0\0""9\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
-  "\0\0\0\0\0\0\0\0\0\0\0\0""4\0\0\0\362\0\0\0\25\0\0\0\0\0\0\0[\0\0\0\331"
-  "\0\0\0:\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0""6\0\0\0\323\0"
-  "\0\0[\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0[\0\0\0\363\0\0\0\234\0\0\0P\0\0\0"
-  "9\0\0\0O\0\0\0\227\0\0\0\360\0\0\0[\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
-  "\0\0\0\0\0\0\25\0\0\0\263\0\0\0\325\0\0\0\377\0\0\0\325\0\0\0\263\0\0"
-  "\0\25\0\0\0\0\0\0\0\0\0\0\0\0"};
-
-
-/* GdkPixbuf RGBA C-Source image dump */
-
-#ifdef __SUNPRO_C
-#pragma align 4 (slider_light_v)
-#endif
-#ifdef __GNUC__
-static const guint8 slider_light_v[] __attribute__ ((__aligned__ (4))) = 
-#else
-static const guint8 slider_light_v[] = 
-#endif
-{ ""
-  /* Pixbuf magic (0x47646b50) */
-  "GdkP"
-  /* length: header (24) + pixel_data (1092) */
-  "\0\0\4\\"
-  /* pixdata_type (0x1010002) */
-  "\1\1\0\2"
-  /* rowstride (52) */
-  "\0\0\0""4"
-  /* width (13) */
-  "\0\0\0\15"
-  /* height (21) */
-  "\0\0\0\25"
-  /* pixel_data: */
-  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
-  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\4\0\0\0!\0"
-  "\0\0`\0\0\0\377\0\0\0\377\0\0\0\206\0\0\0`\0\0\0!\0\0\0\4\0\0\0\0\0\0"
-  "\0\0\0\0\0\0\0\0\0\4\0\0\0;\0\0\0\377\0\0\0\206\0\0\0D\0\0\0-\0\0\0F"
-  "\0\0\0{\0\0\0""4\0\0\0\3\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0!\0\0\0\377\0\0"
-  "\0Y\0\0\0\14\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\12\0\0\0\0\0\0\0\0\0\0\0\0"
-  "\0\0\0\0\0\0\0\0\0\0\0`\0\0\0\206\0\0\0\14\0\0\0\0\0\0\0\0\0\0\0\0\0"
-  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\0\0"
-  "\0\77\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
-  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\0\0\0%\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
-  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377"
-  "\0\0\0%\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
-  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\0\0\0%\0\0\0\0\0\0\0\0\0\0\0\0\0"
-  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
-  "\377\0\0\0%\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
-  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\0\0\0%\0\0\0\0\0\0\0\0\0\0\0"
-  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
-  "\0\0\377\0\0\0%\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
-  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\0\0\0%\0\0\0\0\0\0\0\0\0"
-  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
-  "\0\0\0\0\377\0\0\0%\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
-  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\377\0\0\0%\0\0\0\0\0\0\0"
-  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
-  "\0\0\0\0\0\0\377\0\0\0\77\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
-  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0`\0\0\0\206\0\0\0\14"
-  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
-  "\0\0\0\0\0\0\0\0\0!\0\0\0\206\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
-  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\4\0\0\0;\0\0\0"
-  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
-  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\4\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
-  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
-  "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
-  "\0\0\0\0\0"};
-
-
 /* GdkPixbuf RGBA C-Source image dump */
 
 #ifdef __SUNPRO_C
@@ -437,16 +365,16 @@ static const guint8 check_x_on[] =
   /* height (9) */
   "\0\0\0\11"
   /* pixel_data: */
-  "\0\0\0|\0\0\0\377\0\0\0|\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0|\0\0\0\377\0\0"
-  "\0|\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0|\0\0\0\0\0\0\0|\0\0\0\377\0\0"
-  "\0\377\0\0\0\377\0\0\0|\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0|\0\0\0\377"
-  "\0\0\0\377\0\0\0\377\0\0\0|\0\0\0\0\0\0\0|\0\0\0\377\0\0\0\377\0\0\0"
-  "\377\0\0\0\377\0\0\0\377\0\0\0|\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0|\0\0\0"
-  "\377\0\0\0\377\0\0\0\377\0\0\0|\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0|\0\0\0"
-  "\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0|\0\0\0\0\0\0\0|\0"
-  "\0\0\377\0\0\0\377\0\0\0\377\0\0\0|\0\0\0\377\0\0\0\377\0\0\0\377\0\0"
-  "\0|\0\0\0\377\0\0\0\377\0\0\0\377\0\0\0|\0\0\0\0\0\0\0|\0\0\0\377\0\0"
-  "\0\377\0\0\0\377\0\0\0|\0\0\0\377\0\0\0|\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
-  "\0|\0\0\0\377\0\0\0|"};
+  "\0\0\0|\0\0\0\324\0\0\0|\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0|\0\0\0\324\0\0"
+  "\0|\0\0\0\324\0\0\0\324\0\0\0\324\0\0\0|\0\0\0\0\0\0\0|\0\0\0\324\0\0"
+  "\0\324\0\0\0\324\0\0\0|\0\0\0\324\0\0\0\324\0\0\0\324\0\0\0|\0\0\0\324"
+  "\0\0\0\324\0\0\0\324\0\0\0|\0\0\0\0\0\0\0|\0\0\0\324\0\0\0\324\0\0\0"
+  "\324\0\0\0\324\0\0\0\324\0\0\0|\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0|\0\0\0"
+  "\324\0\0\0\324\0\0\0\324\0\0\0|\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0|\0\0\0"
+  "\324\0\0\0\324\0\0\0\324\0\0\0\324\0\0\0\324\0\0\0|\0\0\0\0\0\0\0|\0"
+  "\0\0\324\0\0\0\324\0\0\0\324\0\0\0|\0\0\0\324\0\0\0\324\0\0\0\324\0\0"
+  "\0|\0\0\0\324\0\0\0\324\0\0\0\324\0\0\0|\0\0\0\0\0\0\0|\0\0\0\324\0\0"
+  "\0\324\0\0\0\324\0\0\0|\0\0\0\324\0\0\0|\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
+  "\0|\0\0\0\324\0\0\0|"};
 
 
